@@ -167,9 +167,9 @@ class TaskJugglerScheduler(SchedulerBase):
             for data in lines:
                 id_line = data[0]
                 entity_id = int(id_line.split('.')[-1].split('_')[-1])
-                logger.debug('updating entity with id : %s' % entity_id)
+                #logger.debug('updating entity with id : %s' % entity_id)
                 entity = Entity.query.filter(Entity.id == entity_id).first()
-                logger.debug('updating : %s' % entity)
+                #logger.debug('updating : %s' % entity)
                 if entity:
                     start_date = datetime.datetime.strptime(
                         data[1], "%Y-%m-%d-%H:%M"
@@ -178,12 +178,12 @@ class TaskJugglerScheduler(SchedulerBase):
                         data[2],
                         "%Y-%m-%d-%H:%M"
                     )
-                    logger.debug('   start : %s' % start_date)
-                    logger.debug('     end : %s' % end_date)
+                    #logger.debug('   start : %s' % start_date)
+                    #logger.debug('     end : %s' % end_date)
 
                     entity.computed_start = start_date
                     entity.computed_end = end_date
-                    logger.debug('updated : %s' % entity)
+                    #logger.debug('updated : %s' % entity)
         logger.debug('completed parsing csv file')
 
     def schedule(self):
@@ -246,5 +246,3 @@ class TaskJugglerScheduler(SchedulerBase):
 
         # remove the tjp file
         #self._clean_up()
-
-
